@@ -2,9 +2,9 @@
 #
 package Test::Base;
 use 5.006001;
-use Spiffy 0.29 -Base;
+use Spiffy 0.30 -Base;
 use Spiffy ':XXX';
-our $VERSION = '0.48';
+our $VERSION = '0.51';
 
 my @test_more_exports;
 BEGIN {
@@ -16,6 +16,7 @@ BEGIN {
         $TODO
     );
 }
+
 use Test::More import => \@test_more_exports;
 use Carp;
 
@@ -75,11 +76,18 @@ sub import() {
 #           unless $default_class->isa($class);
 #     }
 
-    if (@_ > 1 and not grep /^-base$/i, @_) {
-        my @args = @_;
-        shift @args;
-        Test::More->import(import => \@test_more_exports, @args);
-    }
+    unless (grep /^-base$/i, @_) {
+        my @args;
+        for (my $ii = 1; $ii <= $#_; ++$ii) {
+            if ($_[$ii] eq '-package') {
+                ++$ii;
+            } else {
+                push @args, $_[$ii];
+            }
+        }
+        Test::More->import(import => \@test_more_exports, @args)
+            if @args;
+     }
     
     _strict_warnings();
     goto &Spiffy::import;
@@ -1234,9 +1242,29 @@ Test::Base. That happens automatically, due to the powers of Spiffy.
 The first line in C<some_func> allows it to be called as either a
 function or a method in the test code.
 
+=head1 DISTRIBUTION SUPPORT
+
+You might be thinking that you do not want to use Test::Base in you
+modules, because it adds an installation dependency. Fear not.
+Module::Build takes care of that.
+
+Just write a Makefile.PL that looks something like this:
+
+    use inc::Module::Install;
+
+    name            'Foo';
+    all_from        'lib/Foo.pm';
+
+    use_test_base;
+
+    WriteAll;
+
+The line with C<use_test_base> will automatically bundle all the code
+the user needs to run Test::Base based tests.
+
 =head1 OTHER COOL FEATURES
 
-Test::Base automatically adds
+Test::Base automatically adds:
 
     use strict;
     use warnings;
